#
# spec file for package python-isort
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global flavor test%{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-isort%{psuffix}
Version:        4.3.10
Release:        2.3
Summary:        A Python utility / library to sort Python imports
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/timothycrosley/isort
Source:         https://files.pythonhosted.org/packages/source/i/isort/isort-%{version}.tar.gz
%if %{with test}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pylama}
BuildRequires:  %{python_module pytest}
BuildRequires:  python-backports.functools_lru_cache
%endif
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-futures
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%ifpython2
Requires:       python-backports.functools_lru_cache
Requires:       python-futures
%endif
%python_subpackages

%description
isort your python imports for you so you don’t have to.

isort is a Python utility / library to sort imports alphabetically,
and automatically separated into sections. It provides a command line
utility, Python library and plugins for various editors to quickly
sort all your imports. It currently cleanly supports Python 2.7 - 3.6 without
any dependencies.

%prep
%setup -q -n isort-%{version}
chmod -x LICENSE

%build
%python_build

%install
%if !%{with test}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%python_expand py.test-%{$python_bin_suffix} -v
%endif

%if !%{with test}
%files %{python_files}
%{python_sitelib}/isort*
%python3_only %{_bindir}/isort
%license LICENSE
%endif

%changelog
* Mon Mar  4 2019 tchvatal@suse.com
- Update to 4.3.10:
  * Fixed Windows incompatibilities (Issue #835)
  * Fixed relative import sorting bug (Issue #417)
  * Fixed "no_lines_before" to also be respected from previous empty sections.
  * Fixed slow-down introduced by finders mechanism by adding a LRU cache (issue #848)
  * Fixed issue #842 default encoding not-set in Python2
  * Restored Windows automated testing
  * Added Mac automated testing
* Mon Mar  4 2019 tchvatal@suse.com
- Fix multibuild name
* Fri Mar  1 2019 tchvatal@suse.com
- Switch to multibuild to avoid cycle with pylama
* Thu Feb 28 2019 jayvdb@gmail.com
- Drop add-editorconfig.patch made redundant by new sdist
- Add fdupes
- Update to v4.3.9
  * Fixed a bug that led to an incompatibility with black: #831
- from 4.3.8
  * Fixed a bug that led to the recursive option not always been available
    from the command line.
- from 4.3.7
  * Expands the finder failsafe to occur on the creation of the finder objects.
- from 4.3.6
  * Fixes a fatal error that occurs if a single finder throws an exception.
    Important as we add more finders that utilize third party libraries.
- from 4.3.5
  + Potentially Interface Breaking:
  * The `-r` option for removing imports has been renamed `-rm` to avoid
    accidental deletions and confusion with the `-rc` recursive option.
  * `__init__.py` has been removed from the default ignore list. The default
    ignore list is now empty - with all items needing to be explicitly ignored.
  * Isort will now by default ignore .tox / venv folders in an effort to be "safe".
    You can disable this behaviour by setting the "--unsafe" flag, this is
    separate from any skip or not skip rules you may have in place.
  * Isort now allows for files missing closing newlines in whitespace check
  * `distutils` support has been removed to simplify setup.py
  + New:
  * Official Python 3.7 Compatibility.
  * Support for using requirements files to auto determine third-paty
    section if pipreqs & requirementslib are installed.
  * Added support for using pyproject.toml if toml is installed.
  * Added support for XDG_HOME if appdirs is installed.
  * An option has been added to enable ignoring trailing comments
    ('ignore_comments') defaulting to False.
  * Added support to enable line length sorting for only specific sections
  * Added a `correctly_sorted` property on the SortsImport to enable more
    intuitive programmatic checking.
  + Fixes:
  * Improved black compatibility.
  * Isort will no detect files in the CWD as first-party.
  * Fixed several cases where '-ns' or 'not_skip' was being incorrectly
    ignored.
  * Fixed sorting of relative path imports ('.', '..', '...', etc).
  * Fixed bugs caused by a failure to maintain order when loading iterables
    from config files.
  * Correctly handle CPython compiled imports and others that need EXT_SUFFIX
    to correctly identify.
  * Fixed handling of Symbolic Links to follow them when walking the path.
  * Fixed handling of relative known_paths.
  * Fixed lack of access to all wrap modes from the CLI.
  * Fixed handling of FIFO files.
  * Fixed a bug that could result in multiple imports being inserted on the
    same line.
* Thu Feb 14 2019 jayvdb@gmail.com
- Revert to using PyPI release by adding add-editorconfig.patch,
  which is needed to allow the test suite to pass.
  https://github.com/timothycrosley/isort/issues/814
* Sat Jul 21 2018 arun@gmx.de
- specfile:
  * be more specific in %%files section
- update to version 4.3.4:
  * Fixed issue #671: isort is corrupting CRLF files
- changes from version 4.3.3:
  * Fixed issue #665: Tabs turned into single spaces
- changes from version 4.3.2:
  * Fixed issue #651: Add imports option is broken
  * Fixed issue #662: An error generated by rewriting .imports to
    . imoprts
* Fri Feb  2 2018 sebix+novell.com@sebix.at
- update to 4.3.1
  * Fixed issue #654: Trailing comma count error
  * Fixed issue #651: Add imports option is broken
  * Fixed issue #650: Wrong error message displayed
- update to 4.3.0
  * Fixed #557: force_alphabetical_sort and force_sort_within_sections can now be utilized together without extra new lines
  * Added --no-lines-before for more granular control over section output
  * Fixed #493: Unwanted conversion to Windows line endings
  * Implemented --version-number to retrieve just the version number without the isort logo
- Remove patch-shebang.patch and replace it with a sed-call
* Wed Jun 21 2017 sebix+novell.com@sebix.at
- update description
- install LICENSE as %%license if possible
- update to 4.2.15
  * Fixed certain one line imports not being successfully wrapped
- update to 4.2.14
  * Fixed #559 & #565: Added missing standard library imports
- update to 4.2.13
  * Fixed #553: Check only and --diff now work together again
- update to 4.2.12
  * Fixed a problem with the wheel distribution
- update to 4.2.11
  * Fixed #546: Can't select y/n/c after latest update
  * Fixed #545: Incorrectly moves future imports above encoding comments
- update to 4.2.9
  * Fixed #428: Check only modifies sorting
  * Fixed #540: Not correctly identifying stdlib modules
- update to 4.2.8
  * Added --virtual-env switch command line option
  * Added --enforce-whitespace option to go along with --check-only for more exact checks (issue #423)
  * Fixed imports with a tailing '' and no space in-between getting removed (issue #425)
  * Fixed issue #299: long lines occasionally not wrapped
  * Fixed issue #432: No longer add import inside class when class starts at top of file after encoding comment
  * Fixed issue #440: Added missing --use-parentheses option to command line tool and documentation
  * Fixed issue #496: import* imports now get successfully identified and reformatted instead of deleted
  * Fixed issue #491: Non ending parentheses withing single line comments no longer cause formatting issues
  * Fixed issue #471: Imports that wrap the maximum line length and contain comments on the last line are no longer rendered incorrectly
  * Fixed issue #436: Force sort within section no longer rearranges comments
  * Fixed issue #473: Force_to_top and force_sort_within_sections now work together
  * Fixed issue #484 & #472: Consistent output with imports of same spelling but different case
  * Fixed issue #433: No longer incorrectly add an extra new-line when comment between imports and function definition
  * Fixed issue #419: Path specification for skipped paths is not Unix/Windows inter-operable.
  * Breaking Changes:
  * Fixed issue #511: All command line options with an underscore, have had the underscore replaced with a dash for consistency. This effects: multi-line, add-import, remove-import, force-adds, --force-single-line-imports, and length-sort.
  * Replaced the --enforce-whitespace option with --ignore-whitespace to restore original behavior of strict whitespace by default
* Fri Mar 24 2017 jmatejek@suse.com
- install LICENSE file
* Mon Mar  6 2017 jmatejek@suse.com
- update for singlespec
* Sat Oct  8 2016 sebix+novell.com@sebix.at
- use github URL to run tests after packaging
* Fri Aug  5 2016 sebix+novell.com@sebix.at
-  patch-shebang.patch: removed superfluous shebang for packaged file main
* Sat Jun 25 2016 arun@gmx.de
- initial version
